### Map of the file:
## 0. WD, files, libraries
## 1. Tables
## 2. Figures
## 3. Supplementary Tables
## 4. Supplementary Figures

# 0. WD, files, libraries -------------------------------------------------

setwd("") # set your working directory to deepthaw/Rnew 

lapply(list('vegan', 'ggplot2','grid','nlme','multcomp',
            'lsmeans','reshape','plyr','dplyr',
            'ggrepel','piecewiseSEM','mvabund','ade4',
            'AICcmodavg','FactoMineR'), require, character.only = TRUE) # check dependencies

source("additional_functions.R")
otutab<-read.table("Bsnowfence_rarefied1000_ggtax.otu",header=T,row.names = 1) # Averaged OTU table from 100 rarefactions at 899 sequences per sample
tax2<-read.table("Bsnowfence_rarefied1000_ggtax_L2.txt",header=T,row.names=1,comment.char = "@") # Taxa summary at phylum level
deseqT<-read.table("deseq_Treatment_TL.txt",header=T,row.names = 1,sep="\t") # results from the DESEQ differential abundance between treatments in the intermediate layer
deseqA<-read.table("deseq_Treatment_AL.txt",header=T,row.names = 1,sep="\t") # results from the DESEQ differential abundance between treatments in the active layer
deseqP<-read.table("deseq_Treatment_PL.txt",header=T,row.names = 1,sep="\t") # results from the DESEQ differential abundance between treatments in the permafrost layer
sf_init<-read.delim("Rmap_bsnowfence_trimmed",header=T,na.strings=NA,sep = ",") # sf_init is the main data file, including all samples and variables
    # depth - cm
    # gram_roots, shrub_roots, forb_roots, root_density - gDW / soil L
    # NH4, NO3 - concentration in the extract - mg / L
    # NH4_gDW, NO3_gDW - concentration in soil - mg / g soil DW
    # moisture - gravimetric moisture content (w:w)
    # Soil_moisture_vol - volumetric moisture content (v:v)
    # OMC - organic matter content (loss on ignition, w:w)
    # rate11, rate21 - averaged intrinsic aerobic respiration rates at 11C and 21C - umol(CO2).h-1 . g(soil organic matter)-1
    # X11_DW_average, X21_DW_average - averaged bulk aerobic respiration rates at 11C and 21C - umol(CO2).h-1 . g(soil dry weight)-1
    # sedge_cover, forb_cover, shrub_cover, total_cover - visual estimates - %
    # C_content - carbon content (w:w)
    # DNA - DNA concentration, QuantIT dsDNA high sensitivity assay (ng/uL)
    # DNAw - Fresh weight of subsample used for DNA extraction (g)
SFdist<-as.dist(read.delim("weighted_unifrac_Consensus_rarefaction1000.txt",row.names=1)) # weighted unifrac distance matrix computed from averaged OTU table


mdsSF<-metaMDS(SFdist,distance="wunifrac",k=2,try=50,trymax=100)
sf<-sf_init[match(rownames(mdsSF$points),(sf_init$SampleID)),] # sf is the main data file reordered, 
                                                               # without the one sample that we did not have DNA extract for

sf$NMDS1=mdsSF$points[,1]
sf$NMDS2=mdsSF$points[,2]

# renaming and processing variables
sf2<-data.frame(SampleID=sf$SampleID,resp=sf$rate11,resp21=sf$rate21,
                respDW=sf$X11_DW_average,resp21DW=sf$X21_DW_average,
                DT=sf$Depth_Treatment,De.nr=sf$depth,
                De.fr=factor(sf$Depthfactor,levels=c("AL","TL","PL")),
                pH=sf$pH,NH4_DW=sf$NH4_gDW,NO3_DW=sf$NO3_gDW,moist=sf$moisture,
                Treatment=sf$Treatment,Rd=sf$root_density, shrub_roots=sf$shrub_roots,
                forb_roots=sf$forb_roots, sedge_roots=sf$gram_roots, OMC=sf$OMC,Q10=sf$Q10,
                Frozenness=as.factor(sf$frozenness),Core=sf$Core,C_content=sf$C_content,DNA=sf$DNA,DNAw=sf$DNAw)
rownames(sf2)<-sf2$SampleID


levels(sf2$De.fr)<-c("Active layer","Intermediate layer","Permafrost layer") 
levels(sf2$Treatment)<-c("Control","Deep-thaw")
levels(sf$Treatment)<-c("Control","Deep-thaw")

pcoasf<-cmdscale(SFdist,k=3,eig=T,add=T) # principal coordinates analyses, "add=T" to avoid negative eigenvalues
sf2$PC1<-pcoasf$points[,1]
sf2$PC2<-pcoasf$points[,2]
sf2$PC3<-pcoasf$points[,3]

##### 1. Tables ----
# Table 1: environmental and respiration ANOVAs, Manyglm, envfit ----
### Responses to depth and treatment
# Values in the first part of Table 1 are F-values and p-values of the following ANOVAs
# soil chemistry variables
omc.mod<-lme(sqrt(OMC)~Treatment*Depthfactor,random=~1|Core,data=sf_init) # square-root transformed
anova(omc.mod) 
c.mod<-lme(C_content~De.fr*Treatment,
           data=subset(sf_init,Core %in% c("C2","C5","C6","SF2","SF5","SF6")), # 3 replicates where all values are present
           random=~1|Core)
anova(c.mod)
ph.mod<-lme(pH~Treatment*Depthfactor,random=~1|Core,data=sf_init)
anova(ph.mod)
nh4.mod<-lme(log(NH4_gDW+10e-5)~Treatment*Depthfactor,random=~1|Core,data=sf_init) # log-transformed added 10e-5 to avoid log(0)
anova(nh4.mod)
moist.mod<-lme(moisture~Treatment*Depthfactor,random=~1|Core,data=sf_init)
anova(moist.mod)
# Respiration ANOVA 
# bulk respiration
DWnewmod<-lme(log(X11_DW_average)~Treatment*Depthfactor,random=~1|Core,data=sf_init)
anova(DWnewmod)
# intrinsic respiration
newmod<-lme(log(rate11)~Treatment*Depthfactor,random=~1|Core,data=sf_init)
anova(newmod)
# Q10
qmod<-lme(Q10~Depthfactor*Treatment,random=~1|Core,data=sf_init)
anova(qmod)

### Manyglm
# Values in the second part of the table are deviation and p-values of the manyglm model, obtained by printing mng.aov (l95)
# As anova.manyglm() may take a long time to run, results are stored as mng.aov
totutab<-data.frame(t(otutab))
mvotu<-mvabund(totutab)
mng<-manyglm(mvotu~sf2$De.fr*sf2$Treatment,random=~1|sf2$Core,family="negative.binomial")
# mng.aov<-anova(mng) # takes a while (>1h) => commented out
# mng.aov


### Envfit
# Values in the third part of the table are directions (Dim1, Dim2) and strength of the association with ordination space (r2, P)
fit_env_sf<-data.frame(row.names=sf$SampleID,pH=sf$pH,NH4=sf$NH4_gDW,
                       OMC=sf$OMC,Roots=sf$root_density,Moisture=sf$moisture)
vec.sp<-envfit(pcoasf$points[,1:2],fit_env_sf,perm=10000)
vec.sp

# Table 2: Multiple regressions ----
# Log-transformed respiration rates are scaled, as well as root density, to be able to compare estimates of fixed effects more easily
df.step<-data.frame(OMC=sf2$OMC,pH=sf2$pH,NH4_gDW=sf2$NH4_DW,Moisture=sf2$moist,
                    rate11_DW=scale(log(sf2$respDW)),rate11=scale(log(sf2$resp)),
                    root_density=scale(sf2$Rd),Core=sf2$Core,PCOA1=(sf2$PC1),
                    trt=sf2$Treatment) # df.step is used for multiple regressions only
pcad<-dudi.pca(df.step[,1:4],scale=T,center=T,scannf=F,nf=2) # all soil variables scaled and centered for PCA
df.step$soil<-pcad$l1[,1] 


### Bulk respiration models
dw_soiltrt<-(lme(rate11_DW~soil*trt,random=~1|Core,data=df.step,method="ML")) # Soil * treatment
# method="ML" as default REML doesn't allow for likelihood-ratio testing
# random=~1|Core allows different intercepts for each soil core (plot), therefore conditional R2 from rsquared() should be used
summary(dw_soiltrt) # Treatment effect on intercept is extracted here (trtDeep-thaw)
AICc(dw_soiltrt) # AICc value is extracted here
rsquared(dw_soiltrt) # R2 is extracted here (Conditional)
summary(lme(rate11_DW~soil,random=~1|Core,data=df.step,subset=trt=="Control",method="ML")) # Control samples slope values
summary(lme(rate11_DW~soil,random=~1|Core,data=df.step,subset=trt=="Deep-thaw",method="ML")) # Deep-thaw samples slope values

dw_soilbacttrt<-lme(rate11_DW~(soil+PCOA1)*trt,random=~1|Core,data=df.step,method="ML") # (Soil + Bacteria) * treatment
summary(dw_soilbacttrt)  # Treatment effect on intercept is extracted here (trtDeep-thaw)
AICc(dw_soilbacttrt) # AICc value is extracted here
rsquared(dw_soilbacttrt) # R2 is extracted here (Conditional)
summary(lme(rate11_DW~soil+PCOA1,random=~1|Core,data=df.step,subset=trt=="Control",method="ML")) # Control samples slope values
summary(lme(rate11_DW~soil+PCOA1,random=~1|Core,data=df.step,subset=trt=="Deep-thaw",method="ML")) # Deep-thaw samples slope values

dw_soilroottrt<-lme(rate11_DW~(soil+root_density)*trt,random=~1|Core,data=df.step,method="ML") # (Soil + Roots) * treatment
summary(dw_soilroottrt) # Treatment effect on intercept is extracted here (trtDeep-thaw)
AICc(dw_soilroottrt) # AICc value is extracted here
rsquared(dw_soilroottrt) # R2 is extracted here (Conditional)
summary(lme(rate11_DW~soil+root_density,random=~1|Core,data=df.step,subset=trt=="Control",method="ML")) # Control samples slope values
summary(lme(rate11_DW~soil+root_density,random=~1|Core,data=df.step,subset=trt=="Deep-thaw",method="ML")) # Deep-thaw samples slope values

dw_rootsoilbactrt<-lme(rate11_DW~(root_density+soil+PCOA1)*trt,random=~1|Core,data=df.step,method="ML") # (Soil + Root + Bacteria) * treatment
summary(dw_rootsoilbactrt) # Treatment effect on intercept is extracted here (trtDeep-thaw)
AICc(dw_rootsoilbactrt) # AICc value is extracted here
rsquared(dw_rootsoilbactrt) # R2 is extracted here (Conditional)
summary(lme(rate11_DW~root_density+soil+PCOA1,random=~1|Core,data=df.step,subset=trt=="Control",method="ML")) # Control samples slope values
summary(lme(rate11_DW~soil+PCOA1+root_density,random=~1|Core,data=df.step,subset=trt=="Deep-thaw",method="ML")) # Deep-thaw samples slope values


### Intrinsic respiration
soiltrt<-(lme(rate11~soil*trt,random=~1|Core,data=df.step,method="ML")) # Soil * treatment
summary(soiltrt) # Treatment effect on intercept is extracted here (trtDeep-thaw)
AICc(soiltrt) # AICc value is extracted here
rsquared(soiltrt) # R2 is extracted here (Conditional)
summary(lme(rate11~soil,random=~1|Core,data=df.step,subset=trt=="Control",method="ML")) # Control samples slope values
summary(lme(rate11~soil,random=~1|Core,data=df.step,subset=trt=="Deep-thaw",method="ML")) # Deep-thaw samples slope values

soilbacttrt<-lme(rate11~(soil+PCOA1)*trt,random=~1|Core,data=df.step,method="ML") # (Soil + Bacteria) * treatment
summary(soilbacttrt) # Treatment effect on intercept is extracted here (trtDeep-thaw)
AICc(soilbacttrt) # AICc value is extracted here
rsquared(soilbacttrt) # R2 is extracted here (Conditional)
summary(lme(rate11~soil+PCOA1,random=~1|Core,data=df.step,subset=trt=="Control",method="ML")) # Control samples slope values
summary(lme(rate11~soil+PCOA1,random=~1|Core,data=df.step,subset=trt=="Deep-thaw",method="ML")) # Deep-thaw samples slope values

soilroottrt<-lme(rate11~(soil+root_density)*trt,random=~1|Core,data=df.step,method="ML") # (Soil + Root) * treatment
summary(soilroottrt) # Treatment effect on intercept is extracted here (trtDeep-thaw)
AICc(soilroottrt) # AICc value is extracted here
rsquared(soilroottrt) # R2 is extracted here (Conditional)
summary(lme(rate11~soil+root_density,random=~1|Core,data=df.step,subset=trt=="Control",method="ML")) # Control samples slope values
summary(lme(rate11~soil+root_density,random=~1|Core,data=df.step,subset=trt=="Deep-thaw",method="ML")) # Deep-thaw samples slope values

rootsoilbactrt<-lme(rate11~(root_density+soil+PCOA1)*trt,random=~1|Core,data=df.step,method="ML") # (Soil + Root + Bacteria) * treatment
summary(rootsoilbactrt) # Treatment effect on intercept is extracted here (trtDeep-thaw)
AICc(rootsoilbactrt) # AICc value is extracted here
rsquared(rootsoilbactrt) # R2 is extracted here (Conditional)
summary(lme(rate11~soil+PCOA1+root_density,random=~1|Core,data=df.step,subset=trt=="Control",method="ML")) # Control samples slope values
summary(lme(rate11~soil+PCOA1+root_density,random=~1|Core,data=df.step,subset=trt=="Deep-thaw",method="ML")) # Deep-thaw samples slope values

###### 2. Figures -----
##### Figure 1 ----
#### Figure 1A: PCOA ----
# next lines are about extracting coordinates from envfit
A<-as.list(vec.sp$vectors)
pvals<-as.data.frame(A$pvals)
arrows<-as.data.frame(A$arrows*sqrt(A$r)/3) # divided by 3 so the arrows aren't bigger than the graph
C<-cbind(arrows,pvals)
Csig<-subset(C, pvals<0.05) # Keep significant variables only
Csig<-cbind(Csig,species=row.names(Csig))

label.x<-paste("PC1 (",round_any((pcoasf$eig/sum(pcoasf$eig))[1]*100,accuracy=0.01),"%)",sep="") # PC1 % variance explained
label.y<-paste("PC1 (",round_any((pcoasf$eig/sum(pcoasf$eig))[2]*100,accuracy=0.01),"%)",sep="") # PC2 % variance explained

# mean + SE of coordinates per depth x treatment combination
xmeans<-summarySE(data=sf2,measurevar="PC1",groupvars=c("Treatment","De.fr"))
ymeans<-summarySE(data=sf2,measurevar="PC2",groupvars=c("Treatment","De.fr"))
names(ymeans)<-c("Treatment","Depth","N","PC2","sd.pc2","se.pc2","ci.pc2")
means<-data.frame(cbind(xmeans,ymeans),frozenness=c("thawed","frozen","frozen","thawed","thawed","frozen"))

# plotting command
ggplot(data=means,aes(x=PC1,y=PC2))+
  theme_minimal()+
  theme(panel.background=element_rect(fill=NA,color="black"),
        panel.grid=element_blank(),
        text=element_text(size=10),
        legend.margin=margin(t=0,b=0,unit="cm"),
        legend.spacing=unit(0.1,"cm"),
        legend.direction="horizontal",
        legend.box="vertical",
        legend.text.align=0,
        legend.box.just="center",
        legend.key.size = unit(0.4,"cm"),
        legend.background=element_rect(fill=NA,color=NA),
        legend.position=c(0.5,0.89)) +
  scale_linetype_manual(values=c(1,0)) +
  geom_errorbar(aes(ymin=PC2-se.pc2,ymax=PC2+se.pc2),
                lwd=0.2,width=0.009) +
  geom_errorbarh(aes(xmin=PC1-se,xmax=PC1+se),lwd=0.2,height=0.02) +
  geom_point(aes(color=Depth,pch=Treatment),size=2.5) +
  annotate(geom="text",
           x=means$PC1-0.02,
           y=means$PC2+0.03,
           label=c("a","b","b","a","a","c"),
           size=3.3)+
  guides(color=F,
         pch=guide_legend("",override.aes=list(lty=NA)))+
  xlab(label.x) + ylab(label.y) +
  geom_segment(data=Csig, # envfit arrows
               aes(x=-0.1,xend=(0.4*Dim1-0.1),y=0.15,yend=(0.4*Dim2+0.15)),
               arrow = arrow(length = unit(0.15, "cm")),colour="blue") + 
  geom_label_repel(data=Csig, # ggrepel to avoid envfit labels overlap
                   aes(x=(0.4*Dim1-0.1),y=(0.4*Dim2+0.15),label=species),
                   nudge_x = -0.02,
                   label.r=unit(0.05,"lines"),
                   label.size=0.05,
                   point.padding=unit(0.05,"lines"),
                   size=2,
                   box.padding=unit(0.05,"lines"),
                   col="blue", 
                   segment.color = NA) + 
  annotate("text",
           label=c("Active layer","Intermediate layer","Permafrost layer"),
           fontface="bold",
           col=c("#F8766D", "#00BA38", "#619CFF"),
           x=c(-0.16,0.035,0.26),
           y=c(0.40,0.40,0.40),
           size=2.98)+ # to replace the color legend
  ylim(-0.15,0.4) + 
  xlim(-0.23,0.35) + 
  coord_fixed(pcoasf$eig[2]/pcoasf$eig[1])  

ggsave("Fig_1A.pdf",width=90,height=76,units = "mm",dpi=1000) 

#### Figure 1B: DESeq ----
deseqT$otu<-rownames(deseqT)
psubT<-filter(deseqT,padj<0.05) # Filter only OTUs which p-value is <0.05 after adjustment
# all OTUs with p<0.05 happen to be in the rarefied dataset, if that is not the case psubT needs to be further filtered out of OTUs not present in the rarefied dataset, or relative abundance information can be removed
rownames(psubT)<-psubT$otu
otutab$otu<-rownames(otutab)
otusubT<-filter(otutab,otu %in% psubT$otu) # get an abundance table of significantly changing OTUs
rownames(otusubT)<-otusubT$otu
rownames(psubT)<-psubT$otu
otusubT<-otusubT[match(rownames(psubT),rownames(otusubT)),] # reorder otu table to match the order of the DESeq file
all.equal(rownames(otusubT),rownames(psubT)) # check
psubT$ab_rar1000<-rowSums(otusubT[,1:34]) # rarefied abundance of the OTUs found in the DESeq file 
psubT$ab_rar1000_pc<-(psubT$ab_rar1000/sum(otutab[,1:34]))*100 # abundance divided by sum of the total OTU table: %
psubT$phyl_namesfull <- gsub("k__Bacteria","Unclassified",
                             gsub("k__.*p__", "", 
                                  gsub("; c__.*", "", 
                                       gsub("; NA.*", "", psubT$taxonomy)
                                       )
                                  )
                             )
psubT$phyla_temp<-recode(psubT$phyl_namesfull,"Acidobacteria"="Acidobacteria",
                         "Actinobacteria"="Actinobacteria",
                         "Bacteroidetes"="Bacteroidetes",
                         "Caldiserica"="Caldiserica",
                         "Firmicutes"="Firmicutes",
                         "Proteobacteria"="Proteobacteria",
                         "TM7"="TM7",
                         "Unclassified"="Unclassified",
                         "Verrucomicrobia"="Verrucomicrobia",
                         .default="Other")
psubT$Phyla<-factor(psubT$phyla_temp,
                    levels=c("Acidobacteria","Actinobacteria","Bacteroidetes","Caldiserica","Firmicutes",
                             "Proteobacteria","TM7","Verrucomicrobia","Unclassified", "Other" )) # change from alphabetical order to have "Unclassified" and "Other" at the end
# Make a list of OTUs per phylum to know proportions of OTUs changing in each phylum
total_otu_T<-deseqT[,7:8] 
total_otu_T$Phyla<-gsub("k__Bacteria","Unclassified",
                      gsub("k__.*p__", "", 
                           gsub("; c__.*", "", 
                                gsub("; NA.*", "", total_otu_T$taxonomy)
                                )
                           )
                      )
total_otu_T$P2<-recode(total_otu_T$Phyla,
                     "Acidobacteria"="Acidobacteria",
                     "Actinobacteria"="Actinobacteria",
                     "Bacteroidetes"="Bacteroidetes",
                     "Caldiserica"="Caldiserica",
                     "Firmicutes"="Firmicutes",
                     "Proteobacteria"="Proteobacteria",
                     "TM7"="TM7",
                     "Unclassified"="Unclassified",
                     "Verrucomicrobia"="Verrucomicrobia",
                     .default="Other")
total_otu_T$P3<-factor(total_otu_T$P2,
                     levels=c("Acidobacteria","Actinobacteria","Bacteroidetes","Caldiserica","Firmicutes",
                              "Proteobacteria","TM7", "Verrucomicrobia","Unclassified","Other" ))

percents_T<-table(psubT$Phyla)/table(total_otu_T$P3)*100 # calculate % of OTUs changing among sum of OTUs for each phylum
perc_trunc_T<-round_any(as.numeric(percents_T),accuracy=0.01)
lvls_T<-paste(levels(total_otu_T$P3),perc_trunc_T,"% of",table(total_otu_T$P3),"OTUs")
levels(psubT$Phyla)<-lvls_T
# Rearrange the dataset by decreasing Phyla and Fold-change for readability
psubT_final<-arrange(psubT,desc(Phyla),desc(log2FoldChange))
psubT_final$fact_abund<-ifelse(psubT_final$ab_rar1000_pc>0.5, "High (>0.5%)","Low") # identify most abundant OTUs (>0.5% of the sum of rarefied reads)
# plotting command
ggplot(psubT_final,
       aes(x=as.numeric(rownames(psubT_final)),y=-log2FoldChange)) + 
  theme_bw()+xlab("") +
  theme(axis.ticks.y=element_blank(),
        axis.text.y=element_blank(),
        legend.position="bottom",
        legend.direction = "vertical",
        panel.grid=element_blank(),
        legend.box="vertical",
        legend.margin=margin(t=-0.5,b=0,unit="cm"),
        legend.background=element_blank(),
        legend.key.size=unit(0.4,"cm"),
        text=element_text(size=10)) +
  ylab("Intermediate layer OTUs abundance (%)\nlog2(fold-change) with deep-thaw treatment") +
  geom_bar(aes(fill=Phyla),
           stat="identity",
           width=1,
           col=NA,
           lwd=0.1) +
  scale_fill_manual(values=c("#a6cee3","#1f78b4","#33a02c","#fb9a99",
                             "#e31a1c","#fdbf6f","#ff7f00","#cab2d6","#6a3d9a","#ffff99"),
                    guide=guide_legend(title="Phyla (% changing of total diversity)")) +
  geom_point(data=psubT_final,
             aes(x=as.numeric(rownames(psubT_final)),y=ab_rar1000_pc,col=fact_abund),
             show.legend = T,
             size=1) +
  scale_color_manual(values=c("black","darkgrey")) +
  guides(col=F,fill=guide_legend("",override.aes = list(shape=NA)))+
  coord_flip()

ggsave("fig1B.png",width=76,height=158,units="mm",dpi=1000)

#### Figure 1C: Taxa summary ----
taxa_names_clean<-gsub("k__Bacteria;","",
                       gsub("p__", "", 
                            gsub("k__Archaea;","",rownames(tax2))
                            )
                       ) # make phyla names more readable
rownames(tax2)<-taxa_names_clean
ttax2<-as.data.frame(t(tax2))
all.equal(rownames(ttax2),as.character(sf$SampleID))
big_ordered_dat <- ttax2[,(order(colSums(ttax2), decreasing=T))] # reorder taxa summary file to have phyla columns sorted by abundance
ordered_dat<-big_ordered_dat[,1:8] # 8 most abundant taxa
ordered_dat$Unclassified<-big_ordered_dat$Other # Unclassified at phylum level
ordered_dat$Other<-rowSums(big_ordered_dat[,c(10:length(big_ordered_dat))]) # everything smaller than unclassified, 10-end as column 9 is Other
ordered_dat$Depth=factor(sf$Depthfactor,levels=c("AL","TL","PL"))
levels(ordered_dat$Depth)<-c("Active layer","Intermediate layer","Permafrost layer")
ordered_dat$Treatment<-sf$Treatment
levels(ordered_dat$Treatment)<-c("Control","Deep-thaw")
ordered_dat.melt<-melt(ordered_dat,variable_name = "phyl_int",id.vars = c("Treatment","Depth"))
ordered_dat.melt$Phyla<-factor(ordered_dat.melt$phyl_int,
                               levels=rev(c("Acidobacteria","Actinobacteria","Bacteroidetes","Caldiserica","Firmicutes",
                                            "Proteobacteria","TM7","Verrucomicrobia","Unclassified","Other"))) # reorder phyla to have Unclassified and Other last
rect <- rbind(data.frame(xmin=1.5, xmax=3.5, ymin=-0.02, ymax=1.02,Treatment = "Control"),
              data.frame(xmin=2.5, xmax=3.5, ymin=-0.02, ymax=1.02,Treatment = "Deep-thaw")) 

# plotting command
ggplot(ordered_dat.melt, 
       aes(x = Depth))+ 
  theme_bw() +
  theme(axis.text.x=element_text(angle=55,hjust=1),legend.position="NA")+ # legend would be redundant with Fig 1B
  facet_wrap(~Treatment)+
  ylab("Phylum relative abundance")+
  geom_rect(data=rect,
            aes(x=NULL,y=NULL,xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax),
            fill=NA,col="black",lty=2)+
  geom_bar(aes(weight=value, fill = (Phyla)),
           position = 'fill',
           width=0.7) + 
  scale_fill_manual(values=rev(c("#a6cee3","#1f78b4","#33a02c","#fb9a99","#e31a1c",
                                 "#fdbf6f","#ff7f00","#cab2d6","#6a3d9a","#ffff99")),
                    guide=guide_legend(title="Phyla (% changing of total diversity)",reverse=T))+
  theme(text=element_text(size=11), 
        legend.key=element_blank(),
        panel.grid=element_blank(),
        strip.background=element_rect(fill="grey90"))+
  xlab(NULL)

ggsave("fig1C.png",width=86,height=86,dpi=1000,units="mm")

## Figure 2: Bulk and intrinsic respiration at 11C ----
sf_init$De.fr<-factor(sf_init$Depthfactor,levels=levels(sf_init$Depthfactor)[c(1,3,2)])
levels(sf_init$De.fr)<-c("Active layer","Intermediate layer","Permafrost layer")
levels(sf_init$Treatment)<-c("Control","Deep-thaw")

# Bulk respiration
yl2<-expression(paste(bold("Bulk:") ,' μmol(CO'[2]*').h'^"-1"*'.g(soil DW)'^'-1'))
ggplot(data=sf_init,
       aes(De.fr,X11_DW_average,fill=Treatment))+ 
  theme_bw()+
  theme(panel.grid=element_blank(),
        legend.margin=margin(t=0,b=0,unit="cm"),
        text=element_text(size=9),
        legend.position=c(0.8,0.8))+
  ylab(yl2)+
  xlab("")+
  stat_summary(fun.data = mean_se,
               aes(pch=Treatment,col=Treatment),
               position=position_dodge(width=-0.4),
               size=0.75)+
  scale_color_manual(values=c("grey70","grey20"))+
  geom_vline(xintercept=2,linetype=3,color="grey70")+
  guides(color=guide_legend(override.aes=list(lty=0)))+
  ylim(0,NA)+
  annotate("text",x=c(3),y=c(0.2),label="Treatment *\nDepth ***\nInteraction n.s.",size=3)+
  annotate("text",x=c(1,2,3),y=c(0,0,0),label=c("A","A","B"),size=3.5)
ggsave("fig2A.pdf",width=86,height=65,dpi=1000,units="mm")

# Intrinsic respiration
yl3<-expression(paste(bold("Intrinsic:") ,' μmol(CO'[2]*').h'^"-1"*'.g(soil OM)'^'-1',sep=" "))
ggplot(data=sf_init,
       aes(De.fr,rate11,fill=Treatment))+ 
  theme_bw()+
  theme(panel.grid=element_blank(),
        legend.margin=margin(t=0,b=0,unit="cm"),
        text=element_text(size=9),
        legend.position="none")+
  ylab(yl3)+
  xlab("")+
  stat_summary(fun.data = mean_se,
               aes(pch=Treatment,col=Treatment),
               position=position_dodge(width=-0.4),
               size=0.75)+
  scale_color_manual(values=c("grey70","grey20"))+
  geom_vline(xintercept=2,linetype=3,color="grey70")+
  guides(color=guide_legend(override.aes=list(lty=0)))+
#  annotate("text",x=c(1.2,3.2),y=c(0.41,0.24),label=c("a","b"),size=4)+
  annotate("text",x=c(3),y=c(0.075),label="Treatment n.s.\nDepth n.s.\nInteraction *",size=3)+
  ylim(0,NA)
ggsave("fig2B.pdf",width=86,height=65,dpi=1000,units="mm")

#### Figure 3 : intercepts and slopes of best multiple regressions ----
# intervals() computes confidence intervals for the parameters of the LMEs 
dw.soilbacttrt.ctr<-intervals(lme(rate11_DW~(soil+PCOA1),random=~1|Core,subset=trt=="Control",data=df.step,method="ML"),which="fixed")$fixed
dw.soilbacttrt.sf<-intervals(lme(rate11_DW~(soil+PCOA1),random=~1|Core,subset=trt=="Deep-thaw",data=df.step,method="ML"),which="fixed")$fixed
soilbacttrt.ctr<-intervals(lme(rate11~(soil+PCOA1),random=~1|Core,subset=trt=="Control",data=df.step,method="ML"),which="fixed")$fixed
soilbacttrt.sf<-intervals(lme(rate11~(soil+PCOA1),random=~1|Core,subset=trt=="Deep-thaw",data=df.step,method="ML"),which="fixed")$fixed

# with 95% CI
slope.df4<-data.frame(mean=c(dw.soilbacttrt.ctr[,2], # gather estimates, upper and lower CI from each model
                             dw.soilbacttrt.sf[,2],
                             soilbacttrt.ctr[,2],
                             soilbacttrt.sf[,2]),
                      up=c(dw.soilbacttrt.ctr[,3],
                           dw.soilbacttrt.sf[,3],
                           soilbacttrt.ctr[,3],
                           soilbacttrt.sf[,3]),
                      low=c(dw.soilbacttrt.ctr[,1],
                            dw.soilbacttrt.sf[,1],
                            soilbacttrt.ctr[,1],
                            soilbacttrt.sf[,1]),
                      type=factor(c(rep(rownames(dw.soilbacttrt.ctr)[1:3],4))),
                      Treatment=c(rep(c(rep("Control",3),
                                        rep("Deep-thaw",3)),
                                      2)),
                      respiration=c(rep("Bulk respiration",6),
                                    rep("Intrinsic respiration",6)))
levels(slope.df4$type)<-c("Int.","Bacterial PCo1","Soil PC1")
slope.lab<-data.frame(xval=c(1.5,1.5,1.5), # significance labels
                      yval=c(-0.5,-0.5,0.5),
                      lab=rep("*",3),
                      respiration=c("Bulk respiration",
                                    "Intrinsic respiration",
                                    "Intrinsic respiration"),
                      type=c("Int.","Bacterial PCo1","Soil PC1"))

# plotting command
ggplot(slope.df4,
       aes(Treatment,mean))+
  geom_hline(yintercept=0,
             lty=2,
             col="lightgrey")+
  geom_errorbar(aes(ymin=low,
                    ymax=up,
                    col=Treatment),
                width=0,
                lwd=0.8)+
  geom_point(aes(col=Treatment,pch=Treatment),size=3)+
  facet_grid(type~respiration, 
             space="free",
             scales="free_y",
             drop=T,
             switch="x")+
  theme_bw()+
  theme(axis.title.x = element_blank(),
        axis.ticks.x=element_blank(),
        panel.spacing = unit(1,"mm"),
        axis.text.x=element_blank(),
        text=element_text(size=10),
        axis.text.y=element_text(size=6),
        legend.position="bottom",
        panel.grid=element_blank())+
  geom_text(data=slope.lab,
            aes(x=xval,
                y=yval,
                label=lab),
            size=8)+
  guides(color=guide_legend(override.aes=list(lty=c(0,0))))+
  ylab("Intercept or slope (estimate and 95% CI)")+
  scale_color_manual(values=c("darkgrey","black"))

ggsave("Fig_3.pdf",width=86,height=120,units="mm",dpi=1000)

###### 3. Supplementary tables ---------------------------------------
# SI Table S3: post-hoc on environmental variables ----

# estimates, SE, df, t.ratio and p.value are in the table
lsmeans(omc.mod,pairwise~Depthfactor)$contrasts
lsmeans(c.mod,pairwise~De.fr)$contrasts # n=3
lsmeans(ph.mod,pairwise~Depthfactor)$contrasts
lsmeans(ph.mod,pairwise~Depthfactor:Treatment)$contrasts # For depth x treatment interaction, only pertinent comparisons were kept
                                                         # i.e. treatment effect at each depth and depth effect within each treatment
lsmeans(moist.mod,pairwise~Depthfactor)$contrasts


# SI Table S4: ManyGLM post-hoc ----
## Following Manyglms use a depth:treatment interaction with different baseline level of the interaction factor, to provide uncorrected p-values for each possible pairwise comparison
levels(sf2$DT) # the original baseline is C_AL = Control Active Layer
mngcal<-manyglm(mvotu~sf2$DT,random=~1|sf2$Core,family="negative.binomial")
sum.mngCAL<-summary(mngcal)
sf2$DT_CPL<-factor(sf2$DT,levels=levels(sf2$DT)[c(2,1,3,4,5,6)])
levels(sf2$DT_CPL) # just to check that the baseline is right (DT_CPL -> CPL as baseline)
mngcpl<-manyglm(mvotu~sf2$DT_CPL,random=~1|sf2$Core,family="negative.binomial")
sum.mngCPL<-summary(mngcpl)
sf2$DT_CTL<-factor(sf2$DT,levels=levels(sf2$DT)[c(3,1,2,4,5,6)])
levels(sf2$DT_CTL)
mngctl<-manyglm(mvotu~sf2$DT_CTL,random=~1|sf2$Core,family="negative.binomial")
sum.mngCTL<-summary(mngctl)
sf2$DT_SFAL<-factor(sf2$DT,levels=levels(sf2$DT)[c(4,1,2,3,5,6)])
levels(sf2$DT_SFAL)
mngsfal<-manyglm(mvotu~sf2$DT_SFAL,random=~1|sf2$Core,family="negative.binomial")
sum.mngSFAL<-summary(mngsfal)
sf2$DT_SFTL<-factor(sf2$DT,levels=levels(sf2$DT)[c(6,1,2,3,4,5)])
levels(sf2$DT_SFTL)
mngsftl<-manyglm(mvotu~sf2$DT_SFTL,random=~1|sf2$Core,family="negative.binomial")
sum.mngSFTL<-summary(mngsftl)
p<-c(sum.mngCAL$coefficients[,2][2:6],sum.mngCPL$coefficients[,2][2:6],sum.mngCTL$coefficients[,2][2:6],sum.mngSFAL$coefficients[,2][2:6],sum.mngSFTL$coefficients[,2][2:6])
p.corr<-p.adjust(p,method="holm")
write.table(p.corr,file="corrected.manyglm.posthoc.pvals.txt") # adjusted p-values should match the adequate comparisons
manyglm.sum<-rbind(sum.mngCAL$coefficients,sum.mngCPL$coefficients,sum.mngCTL$coefficients,sum.mngSFAL$coefficients,sum.mngSFTL$coefficients)
write.table(manyglm.sum,"manyglm.posthoc.test.summary.txt")


# SI Table S5: respiration post-hoc ----
## Both temperatures
respdf<-data.frame(SampleID=sf_init$SampleID,resp=c(sf_init$rate11,sf_init$rate21),respDW=c(sf_init$X11_DW_average,sf_init$X21_DW_average),Treatment=sf_init$Treatment,Depth=factor(sf_init$Depthfactor,levels=c("AL","TL","PL")),Temperature=as.factor(c(rep(11,36),rep(21,36))), Core=sf_init$Core)
levels(respdf$Depth)<-c("Active layer","Intermediate layer","Permafrost")
levels(respdf$Temperature)<-c(paste("11°C"),paste("21°C"))
# Bulk respiration
respmodDW<-lme(log(respDW)~Depth*Treatment*Temperature,random=~1|Core,data=respdf) 
anova(respmodDW) 
# Intrinsic respiration
respmod<-lme(log(resp)~Depth*Treatment*Temperature,random=~1|Core,data=respdf) 
anova(respmod) 

lsmeans(DWnewmod,pairwise~Depthfactor)$contrasts
lsmeans(DWnewmod,pairwise~Treatment)$contrasts
lsmeans(newmod,pairwise~Depthfactor:Treatment)$contrasts  # For depth x treatment interaction, only pertinent comparisons were kept
                                                          # i.e. treatment effect at each depth and depth effect within each treatment
lsmeans(qmod,pairwise~Depthfactor)$contrasts # qmod from Table 1
lsmeans(qmod,pairwise~Depthfactor:Treatment)$contrasts  # For depth x treatment interaction, only pertinent comparisons were kept
                                                        # i.e. treatment effect at each depth and depth effect within each treatment


##### SI Table S6: Multiple regressions (includes those found above in Table 3) ----
# uses df.step from Table 2
# method="ML" as default REML doesn't allow for likelihood-ratio testing
# random=~1|Core allows different intercepts for each soil core (plot), therefore conditional R2 from rsquared() should be used

## A: Bulk respiration
# models without treatment effect
dw_soil<-(lme(rate11_DW~soil,random=~1|Core,data=df.step,method="ML")) # Soil
summary(dw_soil) # intercepts and slopes
AICc(dw_soil) # AICc
rsquared(dw_soil) # rsquared (conditional)
dw_soilbact<-lme(rate11_DW~soil+PCOA1,random=~1|Core,data=df.step,method="ML") # soil + bacteria
summary(dw_soilbact)# intercepts and slopes
AICc(dw_soilbact)# AICc
rsquared(dw_soilbact) # rsquared (conditional)
dw_soilroot<-lme(rate11_DW~soil+root_density,random=~1|Core,data=df.step,method="ML") # soil + roots
summary(dw_soilroot)# intercepts and slopes
AICc(dw_soilroot)# AICc
rsquared(dw_soilroot) # rsquared (conditional)
dw_rootsoilbac<-lme(rate11_DW~root_density+soil+PCOA1,random=~1|Core,data=df.step,method="ML") # soil + roots + bacteria
summary(dw_rootsoilbac)# intercepts and slopes
AICc(dw_rootsoilbac)# AICc
rsquared(dw_rootsoilbac) # rsquared (conditional)
dw_bact<-lme(rate11_DW~PCOA1,random=~1|Core,data=df.step,method="ML") # bacteria  
summary(dw_bact)# intercepts and slopes
AICc(dw_bact)# AICc
rsquared(dw_bact) # rsquared (conditional)

# models with treatment effect on intercept only (predictors + treatment)
dw_soiltrt2<-(lme(rate11_DW~soil+trt,random=~1|Core,data=df.step,method="ML")) # soil + treatment
summary(dw_soiltrt2)# intercepts and slopes
AICc(dw_soiltrt2)# AICc
rsquared(dw_soiltrt2) # rsquared (conditional)
dw_soilbacttrt2<-lme(rate11_DW~(soil+PCOA1)+trt,random=~1|Core,data=df.step,method="ML") # soil + bacteria + treatment
summary(dw_soilbacttrt2)# intercepts and slopes
AICc(dw_soilbacttrt2)# AICc
rsquared(dw_soilbacttrt2) # rsquared (conditional)
dw_soilroottrt2<-lme(rate11_DW~(soil+root_density)+trt,random=~1|Core,data=df.step,method="ML") # soil + root + treatment
summary(dw_soilroottrt2)# intercepts and slopes
AICc(dw_soilroottrt2)# AICc
rsquared(dw_soilroottrt2) # rsquared (conditional)
dw_rootsoilbactrt2<-lme(rate11_DW~soil+root_density+PCOA1+trt,random=~1|Core,data=df.step,method="ML") # soil + root + bacteria + treatment
summary(dw_rootsoilbactrt2)# intercepts and slopes
AICc(dw_rootsoilbactrt2)# AICc
rsquared(dw_rootsoilbactrt2) # rsquared (conditional)
dw_bacttrt2<-lme(rate11_DW~PCOA1+trt,random=~1|Core,data=df.step,method="ML") # bacteria + treatment
summary(dw_bacttrt2)# intercepts and slopes
AICc(dw_bacttrt2)# AICc
rsquared(dw_bacttrt2) # rsquared (conditional)

# models with treatment effect on slopes and intercept (interaction, predictors * treatment) are in Table 2 except Bacteria * treatment
dw_bacttrt<-lme(rate11_DW~PCOA1*trt,random=~1|Core,data=df.step,method="ML") # Bacteria * treatment
summary(dw_bacttrt) # treatment effect on intercept
summary(lme(rate11_DW~PCOA1,random=~1|Core,data=df.step,subset=trt=="Control",method="ML")) # Control slopes
summary(lme(rate11_DW~PCOA1,random=~1|Core,data=df.step,subset=trt=="Deep-thaw",method="ML")) # Deep-thaw slopes
AICc(dw_bacttrt) # AICc
rsquared(dw_bacttrt) # R squared (conditional)

# The following likelihood-ratio tests look at whether the interactions between treatment and predictors are significant
anova(dw_soiltrt,dw_soiltrt2) # interaction n.s.
anova(dw_soilbacttrt,dw_soilbacttrt2) # interactions n.s.
anova(dw_soilroottrt,dw_soilroottrt2) # interactions n.s.
anova(dw_rootsoilbactrt,dw_rootsoilbactrt2) # interactions n.s.


## B: intrinsic respiration
# models without treatment effect
soil<-(lme(rate11~soil,random=~1|Core,data=df.step,method="ML")) # soil
summary(soil) # intercept and slopes
AICc(soil) # AICc
rsquared(soil) # R squared (conditional)
soilbact<-lme(rate11~soil+PCOA1,random=~1|Core,data=df.step,method="ML") # soil + bacteria
summary(soilbact)# intercept and slopes
AICc(soilbact) # AICc
rsquared(soilbact)# R squared (conditional)
soilroot<-lme(rate11~soil+root_density,random=~1|Core,data=df.step,method="ML") # soil + roots
summary(soilroot)# intercept and slopes
AICc(soilroot) # AICc
rsquared(soilroot)# R squared (conditional)
rootsoilbac<-lme(rate11~root_density+soil+PCOA1,random=~1|Core,data=df.step,method="ML") # soil + bacteria + roots
summary(rootsoilbac)# intercept and slopes
AICc(rootsoilbac) # AICc
rsquared(rootsoilbac)# R squared (conditional)
bact<-lme(rate11~PCOA1,random=~1|Core,data=df.step,method="ML") # bacteria
summary(bact)# intercept and slopes
AICc(bact) # AICc
rsquared(bact)# R squared (conditional)

# models with treatment effect on intercept only (predictors + treatment)
soiltrt2<-(lme(rate11~soil+trt,random=~1|Core,data=df.step,method="ML")) # soil + treatment
summary(soiltrt2)# intercept and slopes
AICc(soiltrt2)# AICc
rsquared(soiltrt2)# R squared (conditional)
soilbacttrt2<-lme(rate11~(soil+PCOA1)+trt,random=~1|Core,data=df.step,method="ML")# soil + bacteria + treatment
summary(soilbacttrt2)# intercept and slopes
AICc(soilbacttrt2)# AICc
rsquared(soilbacttrt2)# R squared (conditional)
soilroottrt2<-lme(rate11~(soil+root_density)+trt,random=~1|Core,data=df.step,method="ML")# soil + roots + treatment
summary(soilroottrt2)# intercept and slopes
AICc(soilroottrt2)# AICc
rsquared(soilroottrt2)# R squared (conditional)
rootsoilbactrt2<-lme(rate11~(root_density+soil+PCOA1)+trt,random=~1|Core,data=df.step,method="ML")# soil + bacteria + roots + treatment
summary(rootsoilbactrt2)# intercept and slopes
AICc(rootsoilbactrt2)# AICc
rsquared(rootsoilbactrt2)# R squared (conditional)
bacttrt2<-lme(rate11~PCOA1+trt,random=~1|Core,data=df.step,method="ML")# bacteria  + treatment
summary(bacttrt2)# intercept and slopes
AICc(bacttrt2)# AICc
rsquared(bacttrt2)# R squared (conditional)

# models with treatment effect on slopes and intercept (interaction, predictors * treatment) are in Table 2 except Bacteria * treatment
bacttrt<-lme(rate11~PCOA1*trt,random=~1|Core,data=df.step,method="ML") # bacteria * treatment
AICc(bacttrt) # AICc
rsquared(bacttrt) # R squared (conditional)
summary(bacttrt) # treatment effect
summary(lme(rate11~PCOA1,random=~1|Core,subset=trt=="Control",data=df.step,method="ML")) # slopes for Control
summary(lme(rate11~PCOA1,random=~1|Core,subset=trt=="Deep-thaw",data=df.step,method="ML")) # slopes for Deep-thaw
anova(bacttrt,soilbacttrt)# no significant differences, i.e. no point in adding soil except gaining 0.08 R2
anova(bacttrt,soiltrt) # can't likelihood-ratio test with equal number of df but AICc difference is large enough to support bacteria only is better (R-squared is also higher)

# The following likelihood-ratio tests look at whether the interactions between treatment and predictors are significant
anova(soiltrt,soiltrt2) # soil:treatment interaction significant
soilbacttrt3<-lme(rate11~soil*trt+PCOA1,random=~1|Core,data=df.step,method="ML") # soil:treatment interaction but not bacteria:treatment
soilbacttrt4<-lme(rate11~soil+PCOA1*trt,random=~1|Core,data=df.step,method="ML") # bacteria:treatment interaction but not soil:treatment
anova(soilbacttrt,soilbacttrt2) # at least one interaction significant
anova(soilbacttrt,soilbacttrt3) # PCOA1:treatment interaction significant
anova(soilbacttrt2,soilbacttrt4) # soil:treatment interaction significant
soilroottrt3<-lme(rate11~soil*trt+root_density,random=~1|Core,data=df.step,method="ML") #soil:treatment interaction but not root:treatment
soilroottrt4<-lme(rate11~soil+root_density*trt,random=~1|Core,data=df.step,method="ML") # root:treatment interaction but not soil:treatment
anova(soilroottrt,soilroottrt2) # at least one interaction significant
anova(soilroottrt2,soilroottrt3) # soil:treatment interaction significant
anova(soilroottrt2,soilroottrt4) # root:treatment interaction significant
rootsoilbactrt3<-lme(rate11~root_density+soil+PCOA1*trt,random=~1|Core,data=df.step,method="ML") # only bacteria:treatment
rootsoilbactrt4<-lme(rate11~root_density+soil*trt+PCOA1,random=~1|Core,data=df.step,method="ML") # only soil:treatment
rootsoilbactrt5<-lme(rate11~root_density*trt+soil+PCOA1,random=~1|Core,data=df.step,method="ML") # only root:treatment
anova(rootsoilbactrt,rootsoilbactrt2) # at least one interaction significant
anova(rootsoilbactrt2,rootsoilbactrt3) # PCOA1:treatment interaction significant
anova(rootsoilbactrt2,rootsoilbactrt4) # soil:treatment interaction significant
anova(rootsoilbactrt2,rootsoilbactrt5) # root:treatment interaction significant

###### 4. Supplementary Figures ----
#### Supplementary Figure S1: DNA concentrations ----
ggplot(aes(x=De.fr,
           y=DNA,
           col=Treatment),
       data=sf2)+
  stat_summary(fun.data = mean_se,
               aes(pch=Treatment,col=Treatment),
               position=position_dodge(width=-0.4),
               size=0.75)+
  scale_color_manual(values=c("grey70","grey20"))+
  theme_bw()+
  theme(panel.grid=element_blank())+
  geom_vline(xintercept=2,linetype=3,color="grey70")+
  xlab("Depth")+
  ylab("Extracted DNA (ng / μL)")
ggsave("SI_fig_S1A.pdf",width=150,height=80,units="mm")
ggplot(aes(x=De.fr,
           y=DNA*40/(DNAw*(1-moist)),
           col=Treatment),
       data=sf2)+
  stat_summary(fun.data = mean_se,
               aes(pch=Treatment,col=Treatment),
               position=position_dodge(width=-0.4),
               size=0.75)+
  scale_color_manual(values=c("grey70","grey20"))+
  theme_bw()+
  theme(panel.grid=element_blank())+
  geom_vline(xintercept=2,linetype=3,color="grey70")+
  xlab("Depth")+
  ylab("Extracted DNA (ng / g(soil DW))")
ggsave("SI_fig_S1B.pdf",width=150,height=80,units="mm")

#### Supplementary Figure S2: PCA Biplot ----
png(filename="SI_Fig_S2.png",
    width=160,
    height=120,
    units="mm",
    res = 1000)
par(mfrow=c(1,2))
PCA(df.step[,1:4],scale.unit = T) # used FactoMineR for plotting convenience here
# biplot(pcad)
dev.off()

#### Supplementary Figure S3: Depth & Treatment effect on soil chemistry ----
# summarySE could be replaced by ggplot's stat_summary, it computes mean and SE 
omc.bars<-summarySE(sf_init,measurevar="OMC",groupvars=c("De.fr","Treatment"))
omc.bars$type<-"Organic matter content (g / g(soilDW))"
c.bars<-summarySE(subset(sf_init,Core %in% c("C2","C5","C6","SF2","SF5","SF6")),measurevar="C_content",groupvars=c("De.fr","Treatment"))
c.bars$type<-"Carbon content (g / g(soilDW))"
moist.bars<-summarySE(sf_init,measurevar="moisture",groupvars=c("De.fr","Treatment"))
moist.bars$type<-"Moisture content (g / g(soilDW))"
ph.bars<-summarySE(sf_init,measurevar = "pH",groupvars = c("De.fr","Treatment"))
ph.bars$type<-"pH"
nh4.bars<-summarySE(sf_init,measurevar="NH4_gDW",groupvars=c("De.fr","Treatment"))
nh4.bars$type<-"Ammonium (mg / g(soilDW))"
grid.df<-rbind(omc.bars,
               setNames(c.bars,names(omc.bars)),
               setNames(moist.bars,names(omc.bars)),
               setNames(ph.bars,names(omc.bars)),
               setNames(nh4.bars,names(omc.bars))) # make one data frame with summaries of the variables
grid.df$type<-factor(grid.df$type,levels=c("Moisture content (g / g(soilDW))","pH","Ammonium (mg / g(soilDW))","Organic matter content (g / g(soilDW))","Carbon content (g / g(soilDW))"))
levels(grid.df$Treatment)<-c("Control","Deep-thaw")
signif.df<-data.frame(x=c(1,2,3,1,2,3,1,2,3,0.77,2.77), # dataframe 
                      y=c(0.85,0.85,0.32,0.45,0.45,0.15,0.85,0.85,0.7,5,6),
                      type=c("Organic matter content (g / g(soilDW))",
                             "Organic matter content (g / g(soilDW))",
                             "Organic matter content (g / g(soilDW))",
                             "Carbon content (g / g(soilDW))",
                             "Carbon content (g / g(soilDW))",
                             "Carbon content (g / g(soilDW))",
                             "Moisture content (g / g(soilDW))",
                             "Moisture content (g / g(soilDW))",
                             "Moisture content (g / g(soilDW))","pH","pH"),
                      labs=c("A","A","B","A","A","B","A","A","B","a","b"),
                      Treatment="Control",
                      De.fr="AL")
# plotting command
ggplot(data=grid.df,aes(De.fr,OMC,fill=Treatment))+
  theme_bw()+ 
  geom_bar(colour="black",
           position=position_dodge(),
           stat="identity",
           alpha=0.8) + ylab("") + xlab("")+
  theme(strip.background=element_blank(),
        strip.placement="outside",
        text=element_text(size=10),
        axis.text.x=element_text(angle=45,hjust=1),
        panel.grid=element_blank(),
        legend.position=c(0.8,0.15),
        legend.key.size=unit(0.3,"cm"))+
  ggtitle("") + 
  geom_errorbar(aes(ymin=OMC-se,ymax=OMC+se),
                width=0.2,
                position=position_dodge(0.9))+
  scale_fill_manual(values =c("darkgrey","white","blue"))+
  facet_wrap(facets="type",scale="free_y",strip.position="left",as.table=T) +
  geom_text(data=signif.df,
            aes(x=x,y=y,label=labs),
            size=4)

ggsave("SI_Fig_S3.pdf",width=170,height=150,units="mm",dpi=1000)

#### Supplementary Figure S4: Root density, total and per functional type ----
df.root<-data.frame(Rd=sf2$Rd, # dataframe with root densities, Rd is total root density
                    sedge_roots=sf2$sedge_roots,
                    shrub_roots=sf2$shrub_roots,
                    forb_roots=sf2$forb_roots,
                    De.fr=sf2$De.fr,Treatment=sf2$Treatment)
root.melt<-melt(df.root,
                measurevars=c("Rd","sedge_roots","shrub_roots","forb_roots"),
                id.vars = c("De.fr","Treatment"),
                variable_name = "type")
levels(root.melt$type)<-c("Total root density","Sedges","Shrubs","Forbs")
# plotting command
ggplot(data=root.melt,
       aes(De.fr,value)) + 
  theme_bw()+
  theme(text=element_text(size=10),
        panel.grid=element_blank(),
        axis.text.x=element_text(angle=55,hjust=1))+
  ylab("Root density (gDW / L soil)")+
  xlab("")+
  facet_grid(.~type)+
  stat_summary(fun.data = mean_se,
               geom="bar",
               aes(fill=Treatment),
               col="black",
               position=position_dodge(0.9))+
  stat_summary(fun.data = mean_se,
               geom="errorbar",
               aes(fill=Treatment),
               position=position_dodge(0.9),
               width=0.2,
               color="black")+
  scale_fill_manual(values=c("darkgrey","white"))
ggsave("SI_fig_S4.pdf",width=170,height=126,units="mm",dpi=1000)

#### Supplementary Figure S5: Differential abundance of OTUs in active layer and permafrost layer ----
## Supplementary Figure S5-A : Active layer ----
deseqA$otu<-rownames(deseqA)
psubA<-filter(deseqA,padj<0.05) # Filter only OTUs which p-value is <0.05 after adjustment
rownames(psubA)<-psubA$otu
otutab$otu<-rownames(otutab)
psubA<-filter(psubA,otu %in% otutab$otu)
otusubA<-filter(otutab,otu %in% psubA$otu) # get an abundance table of significantly changing OTUs
rownames(otusubA)<-otusubA$otu
rownames(psubA)<-psubA$otu
otusubA<-otusubA[match(rownames(psubA),rownames(otusubA)),] # reorder otu table to match the order of the DESeq file
all.equal(rownames(otusubA),rownames(psubA)) # check
psubA$ab_rar1000<-rowSums(otusubA[,1:34]) # rarefied abundance of the OTUs found in the DESeq file 
psubA$ab_rar1000_pc<-(psubA$ab_rar1000/sum(otutab[,1:34]))*100 # abundance divided by sum of the total OTU table: %
psubA$phyl_namesfull <- gsub("k__Bacteria","Unclassified",
                             gsub("k__.*p__", "", 
                                  gsub("; c__.*", "", 
                                       gsub("; NA.*", "", psubA$taxonomy)
                                  )
                             )
)
psubA$phyla_temp<-recode(psubA$phyl_namesfull,"Acidobacteria"="Acidobacteria",
                         "Actinobacteria"="Actinobacteria",
                         "Bacteroidetes"="Bacteroidetes",
                         "Caldiserica"="Caldiserica",
                         "Firmicutes"="Firmicutes",
                         "Proteobacteria"="Proteobacteria",
                         "TM7"="TM7",
                         "Unclassified"="Unclassified",
                         "Verrucomicrobia"="Verrucomicrobia",
                         .default="Other")
psubA$Phyla<-factor(psubA$phyla_temp,
                    levels=c("Acidobacteria","Actinobacteria","Bacteroidetes","Caldiserica","Firmicutes",
                             "Proteobacteria","TM7","Verrucomicrobia","Unclassified", "Other" )) # change from alphabetical order to have "Unclassified" and "Other" at the end
# Make a list of OTUs per phylum to know proportions of OTUs changing in each phylum
total_otu_A<-deseqA[,7:8]
total_otu_A$Phyla<-gsub("k__Bacteria","Unclassified",
                      gsub("k__.*p__", "", 
                           gsub("; c__.*", "", 
                                gsub("; NA.*", "", total_otu_A$taxonomy)
                           )
                      )
)
total_otu_A$P2<-recode(total_otu_A$Phyla,
                     "Acidobacteria"="Acidobacteria",
                     "Actinobacteria"="Actinobacteria",
                     "Bacteroidetes"="Bacteroidetes",
                     "Caldiserica"="Caldiserica",
                     "Firmicutes"="Firmicutes",
                     "Proteobacteria"="Proteobacteria",
                     "TM7"="TM7",
                     "Unclassified"="Unclassified",
                     "Verrucomicrobia"="Verrucomicrobia",
                     .default="Other")
total_otu_A$P3<-factor(total_otu_A$P2,
                     levels=c("Acidobacteria","Actinobacteria","Bacteroidetes","Caldiserica","Firmicutes",
                              "Proteobacteria","TM7", "Verrucomicrobia","Unclassified","Other" ))

percents_A<-table(psubA$Phyla)/table(total_otu_A$P3)*100 # calculate % of OTUs changing among sum of OTUs for each phylum
perc_trunc_A<-round_any(as.numeric(percents_A),accuracy=0.01)
lvls_A<-paste(levels(total_otu_A$P3),perc_trunc_A,"% of",table(total_otu_A$P3),"OTUs")
levels(psubA$Phyla)<-lvls_A
# Rearrange the dataset by decreasing Phyla and Fold-change for readability
psubA_final<-arrange(psubA,desc(Phyla),desc(log2FoldChange))
psubA_final$fact_abund<-ifelse(psubA_final$ab_rar1000_pc>0.5, "High (>0.5%)","Low") # identify most abundant OTUs (>0.5% of the sum of rarefied reads)
# plotting command
ggplot(psubA_final,
       aes(x=as.numeric(rownames(psubA_final)),y=-log2FoldChange)) + 
  theme_bw()+xlab("") +
  theme(axis.ticks.y=element_blank(),
        axis.text.y=element_blank(),
        legend.position="bottom",
        legend.direction = "vertical",
        panel.grid=element_blank(),
        legend.box="vertical",
        legend.margin=margin(t=-0.5,b=0,unit="cm"),
        legend.background=element_blank(),
        legend.key.size=unit(0.4,"cm"),
        text=element_text(size=10)) +
  ylab("Active layer OTUs abundance (%)\nlog2(fold-change) with deep-thaw treatment") +
  geom_bar(aes(fill=Phyla),
           stat="identity",
           width=1,
           col=NA,
           lwd=0.1) +
  scale_fill_manual(values=c("#a6cee3","#1f78b4","#33a02c","#fb9a99",
                             "#e31a1c","#fdbf6f","#ff7f00","#cab2d6","#6a3d9a","#ffff99"),
                    guide=guide_legend(title="Phyla (% changing of total diversity)")) +
  geom_point(data=psubA_final,
             aes(x=as.numeric(rownames(psubA_final)),y=ab_rar1000_pc,col=fact_abund),
             show.legend = T,
             size=1) +
  scale_color_manual(values=c("black","darkgrey")) +
  guides(col=F,fill=guide_legend("",override.aes = list(shape=NA)))+
  coord_flip()
ggsave("SI_Fig_S5A.pdf",width=76,height=170,dpi=1000,units="mm")

## Supplementary Figure S5-B : Permafrost layer ----
deseqP$otu<-rownames(deseqP)
psubP<-filter(deseqP,padj<0.05) # Filter only OTUs which p-value is <0.05 after adjustment
rownames(psubP)<-psubP$otu
otutab$otu<-rownames(otutab)
psubP<-filter(psubP,otu %in% otutab$otu)
otusubP<-filter(otutab,otu %in% psubP$otu) # get an abundance table of significantly changing OTUs
rownames(otusubP)<-otusubP$otu
rownames(psubP)<-psubP$otu
otusubP<-otusubP[match(rownames(psubP),rownames(otusubP)),] # reorder otu table to match the order of the DESeq file
all.equal(rownames(otusubP),rownames(psubP)) # check
psubP$ab_rar1000<-rowSums(otusubP[,1:34]) # rarefied abundance of the OTUs found in the DESeq file 
psubP$ab_rar1000_pc<-(psubP$ab_rar1000/sum(otutab[,1:34]))*100 # abundance divided by sum of the total OTU table: %
psubP$phyl_namesfull <- gsub("k__Bacteria","Unclassified",
                             gsub("k__.*p__", "", 
                                  gsub("; c__.*", "", 
                                       gsub("; NA.*", "", psubP$taxonomy)
                                  )
                             )
)
psubP$phyla_temp<-recode(psubP$phyl_namesfull,"Acidobacteria"="Acidobacteria",
                         "Actinobacteria"="Actinobacteria",
                         "Bacteroidetes"="Bacteroidetes",
                         "Caldiserica"="Caldiserica",
                         "Firmicutes"="Firmicutes",
                         "Proteobacteria"="Proteobacteria",
                         "TM7"="TM7",
                         "Unclassified"="Unclassified",
                         "Verrucomicrobia"="Verrucomicrobia",
                         .default="Other")
psubP$Phyla<-factor(psubP$phyla_temp,
                    levels=c("Acidobacteria","Actinobacteria","Bacteroidetes","Caldiserica","Firmicutes",
                             "Proteobacteria","TM7","Verrucomicrobia","Unclassified", "Other" )) # change from alphabetical order to have "Unclassified" and "Other" at the end
# Make a list of OTUs per phylum to know proportions of OTUs changing in each phylum
total_otu_P<-deseqP[,7:8]
total_otu_P$Phyla<-gsub("k__Bacteria","Unclassified",
                      gsub("k__.*p__", "", 
                           gsub("; c__.*", "", 
                                gsub("; NA.*", "", total_otu_P$taxonomy)
                           )
                      )
)
total_otu_P$P2<-recode(total_otu_P$Phyla,
                     "Acidobacteria"="Acidobacteria",
                     "Actinobacteria"="Actinobacteria",
                     "Bacteroidetes"="Bacteroidetes",
                     "Caldiserica"="Caldiserica",
                     "Firmicutes"="Firmicutes",
                     "Proteobacteria"="Proteobacteria",
                     "TM7"="TM7",
                     "Unclassified"="Unclassified",
                     "Verrucomicrobia"="Verrucomicrobia",
                     .default="Other")
total_otu_P$P3<-factor(total_otu_P$P2,
                     levels=c("Acidobacteria","Actinobacteria","Bacteroidetes","Caldiserica","Firmicutes",
                              "Proteobacteria","TM7", "Verrucomicrobia","Unclassified","Other" ))

percents_P<-table(psubP$Phyla)/table(total_otu_P$P3)*100 # calculate % of OTUs changing among sum of OTUs for each phylum
perc_trunc_P<-round_any(as.numeric(percents_P),accuracy=0.01)
lvls_P<-paste(levels(total_otu_P$P3),perc_trunc_P,"% of",table(total_otu_P$P3),"OTUs")
levels(psubP$Phyla)<-lvls_P
# Rearrange the dataset by decreasing Phyla and Fold-change for readability
psubP_final<-arrange(psubP,desc(Phyla),desc(log2FoldChange))
psubP_final$fact_abund<-ifelse(psubP_final$ab_rar1000_pc>0.5, "High (>0.5%)","Low") # identify most abundant OTUs (>0.5% of the sum of rarefied reads)
# plotting command
ggplot(psubP_final,
       aes(x=as.numeric(rownames(psubP_final)),y=-log2FoldChange)) + 
  theme_bw()+xlab("") +
  theme(axis.ticks.y=element_blank(),
        axis.text.y=element_blank(),
        legend.position="bottom",
        legend.direction = "vertical",
        panel.grid=element_blank(),
        legend.box="vertical",
        legend.margin=margin(t=-0.5,b=0,unit="cm"),
        legend.background=element_blank(),
        legend.key.size=unit(0.4,"cm"),
        text=element_text(size=10)) +
  ylab("Permafrost layer OTUs abundance (%)\nlog2(fold-change) with deep-thaw treatment") +
  geom_bar(aes(fill=Phyla),
           stat="identity",
           width=1,
           col=NA,
           lwd=0.1) +
  scale_fill_manual(values=c("#1f78b4","#33a02c","#fb9a99",
                             "#e31a1c","#fdbf6f","#ff7f00","#cab2d6","#6a3d9a","#ffff99"),
                    guide=guide_legend(title="Phyla (% changing of total diversity)")) +
  geom_point(data=psubP_final,
             aes(x=as.numeric(rownames(psubP_final)),y=ab_rar1000_pc,col=fact_abund),
             show.legend = T,
             size=1) +
  scale_color_manual(values=c("black","darkgrey")) +
  guides(col=F,fill=guide_legend("",override.aes = list(shape=NA)))+
  coord_flip()

ggsave("SI_fig_S5B.pdf",width=76,height=158,units="mm",dpi=1000)

#### Supplementary Figure S6: Temperature sensitivity of respiration ----
tukeys<-c("A","B","AB","a","b") # significance letters for Q10, from SI Table 2
tukeyx<-c(1.95,3,1,1.775,2.775)
tukeyy<-c(0,0,0,2.1,1.3)

ggplot(data=sf_init,
       aes(De.fr,Q10,color=Treatment))+
  theme_bw()+
  theme(panel.grid=element_blank(),
        legend.margin=margin(t=0,b=0,unit="cm"),
        text=element_text(size=9),
        legend.position=c(0.8,0.25))+
  ylab(expression(Q[10]))+
  xlab("")+
  stat_summary(fun.data = mean_se,
               aes(pch=Treatment),
               position=position_dodge(-0.4),
               size=0.75)+
  scale_color_manual(values=c("grey70","grey20"))+
  geom_vline(xintercept=2,linetype=3)+
  guides(color=guide_legend(override.aes=list(lty=0)))+
  ylim(0,NA)+
  annotate("text", 
           x=tukeyx, 
           y=tukeyy,
           label=tukeys)

ggsave("SI_fig_S6.pdf",width=120,height=86,dpi=1000,units="mm")

#### Supplementary Figure S7: Plant cover ----
sedg.bar<-summarySE(sf,measurevar="sedge_cover",groupvars=c("Treatment"))
forb.bar<-summarySE(sf,measurevar="forb_cover",groupvars=c("Treatment"))
shrub.bar<-summarySE(sf,measurevar="shrub_cover",groupvars=c("Treatment"))
total.bar<-summarySE(sf,measurevar="total_cover",groupvars=c("Treatment"))
sedg.bar$type<-"Sedges"
forb.bar$type<-"Forbs"
shrub.bar$type<-"Shrubs"
total.bar$type<-"Total"
cover.bar<-rbind(sedg.bar,
                 setNames(forb.bar,names(sedg.bar)),
                 setNames(shrub.bar,names(sedg.bar)),
                 setNames(total.bar,names(sedg.bar)))
anova(lm(sedge_cover~Treatment,data=sf))
anova(lm(shrub_cover~Treatment,data=sf))
anova(lm(forb_cover~Treatment,data=sf))
anova(lm(total_cover~Treatment,data=sf))
sig.bar<-data.frame(x=rep(1.5,3), # significance *
                    y=rep(85,3),
                    type=c("Sedges","Shrubs","Total"),
                    labs="*",
                    Treatment="Control")
ggplot(data=cover.bar,
       aes(y=sedge_cover,
           Treatment,
           fill=Treatment))+
  geom_bar(position=position_dodge(),
           colour="black",
           stat="identity",
           alpha=0.8)+
  theme_bw()+
  theme(axis.text.x=element_text(angle=55,hjust=1),
        text=element_text(size=10),
        legend.position="right",
        panel.grid=element_blank())+
  ylab("Plant functional type cover in %")+
  xlab("")+
  geom_errorbar(aes(ymin=sedge_cover-se,
                    ymax=sedge_cover+se),
                width=0.2,
                position = position_dodge(0.9))+
  facet_wrap(~type,nrow=1)+
  scale_fill_manual(values =c("darkgrey","white"))+
  geom_text(data=sig.bar,
            aes(x=x,y=y,label=labs),
            size=8)

ggsave("SI_fig5.png",width=170,height=86,units="mm",dpi=1000)

#### Rebuttal Figure A OMC - C_content relationship ----
ggplot(aes(x=OMC*100,
           y=C_content*100,
           col=Treatment),
       data=subset(sf2,Core %in% c("C2","C5","C6","SF2","SF5","SF6")))+
  geom_smooth(method=lm,
              col="deepskyblue3",fill="deepskyblue3",alpha=0.2)+
  geom_point(aes(pch=De.fr))+
  theme_bw()+
  scale_color_manual(values=c("grey70","grey20",NA))+
  guides(pch=guide_legend("Depth"))+
  coord_fixed()+ 
  annotate("text", 
           x = 25, 
           y = 50, 
           label = lm_eqn(lm(C_content~OMC,
                             data=subset(sf2,Core %in% c("C2","C5","C6","SF2","SF5","SF6")))),
           colour="black",
           size = 4, 
           parse=TRUE)+
  xlab("OMC % (g/g)")+
  ylab("Carbon % (g/g)")
ggsave("Rebuttal_fig_A_Ccontent_vs_OMC.png",width=155,height=150,units="mm")

